==> trade-center-api-2.3.88-sources.jar: cn/com/duiba/order/center/api/paramquery/ActivityOrdersPageQuery.java <==
package cn.com.duiba.order.center.api.paramquery;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by sunyan on 2017/10/11.
 */
public class ActivityOrdersPageQuery implements Serializable {

    private static final long serialVersionUID = 1093140189931758291L;
    private Long appId;
    private Long relationId;
    private Integer relationType;
    private Date startDay;
    private Date endDay;
    private Integer offset=0;
    private Integer max=20;
    private String exchangeStatus;
    private String tableName;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getRelationId() {
        return relationId;
    }

    public void setRelationId(Long relationId) {
        this.relationId = relationId;
    }

    public Integer getRelationType() {
        return relationType;
    }

    public void setRelationType(Integer relationType) {
        this.relationType = relationType;
    }

    public Date getStartDay() {
        return startDay;
    }

    public void setStartDay(Date startDay) {
        this.startDay = startDay;
    }

    public Date getEndDay() {
        return endDay;
    }

    public void setEndDay(Date endDay) {
        this.endDay = endDay;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }

    public Integer getMax() {
        return max;
    }

    public void setMax(Integer max) {
        this.max = max;
    }

    public String getTableName() {
        return tableName;
    }

    public void setTableName(String tableName) {
        this.tableName = tableName;
    }

    public String getExchangeStatus() {
        return exchangeStatus;
    }

    public void setExchangeStatus(String exchangeStatus) {
        this.exchangeStatus = exchangeStatus;
    }
}

==> trade-center-api-3.0.13-sources.jar: cn/com/duiba/order/center/api/paramquery/ActivityOrdersPageQuery.java <==
package cn.com.duiba.order.center.api.paramquery;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Created by sunyan on 2017/10/11.
 */
public class ActivityOrdersPageQuery implements Serializable {

    private static final long serialVersionUID = 1093140189931758291L;
    private Long appId;
    private Long relationId;
    private List<Long> relationIds;
    private Integer relationType;
    private Date startDay;
    private Date endDay;
    private Integer offset=0;
    private Integer max=20;
    private String exchangeStatus;
    private String tableName;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getRelationId() {
        return relationId;
    }

    public void setRelationId(Long relationId) {
        this.relationId = relationId;
    }

    public Integer getRelationType() {
        return relationType;
    }

    public void setRelationType(Integer relationType) {
        this.relationType = relationType;
    }

    public Date getStartDay() {
        return startDay;
    }

    public void setStartDay(Date startDay) {
        this.startDay = startDay;
    }

    public Date getEndDay() {
        return endDay;
    }

    public void setEndDay(Date endDay) {
        this.endDay = endDay;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }

    public Integer getMax() {
        return max;
    }

    public void setMax(Integer max) {
        this.max = max;
    }

    public String getTableName() {
        return tableName;
    }

    public void setTableName(String tableName) {
        this.tableName = tableName;
    }

    public String getExchangeStatus() {
        return exchangeStatus;
    }

    public void setExchangeStatus(String exchangeStatus) {
        this.exchangeStatus = exchangeStatus;
    }

    public List<Long> getRelationIds() {
        return relationIds;
    }

    public void setRelationIds(List<Long> relationIds) {
        this.relationIds = relationIds;
    }
}
